[gnome-bluetooth] applet: Update for killswitch API change



commit aaa6dac96a3d8468f1963ec870922f61f3490f44
Author: Bastien Nocera <hadess hadess net>
Date:   Mon Jul 23 17:34:21 2012 +0100

    applet: Update for killswitch API change

 applet/bluetooth-applet.c |    6 +++---
 applet/bluetooth-applet.h |   14 +-------------
 2 files changed, 4 insertions(+), 16 deletions(-)
---
diff --git a/applet/bluetooth-applet.h b/applet/bluetooth-applet.h
index be10e08..267d8a2 100644
--- a/applet/bluetooth-applet.h
+++ b/applet/bluetooth-applet.h
@@ -29,6 +29,7 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 #include <bluetooth-enums.h>
+#include <bluetooth-killswitch.h>
 
 /**
  * BluetoothCapabilities:
@@ -62,19 +63,6 @@ typedef struct {
 
 GType bluetooth_simple_device_get_type (void) G_GNUC_CONST;
 
-/**
- * BluetoothKillswitchState:
- *
- * public version of that found in bluetooth-killswitch.h
- */
-
-typedef enum {
-  BLUETOOTH_KILLSWITCH_STATE_NO_ADAPTER = -1,
-  BLUETOOTH_KILLSWITCH_STATE_SOFT_BLOCKED = 0,
-  BLUETOOTH_KILLSWITCH_STATE_UNBLOCKED,
-  BLUETOOTH_KILLSWITCH_STATE_HARD_BLOCKED
-} BluetoothKillswitchState;
-
 /*
  * Type macros.
  */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/applet/bluetooth-applet.c b/applet/bluetooth-applet.c
index 32d373e..a840e10 100644
--- a/applet/bluetooth-applet.c
+++ b/applet/bluetooth-applet.c
@@ -632,7 +632,7 @@ device_has_uuid (const char **uuids, const char *uuid)
 }
 
 static void
-killswitch_state_change (BluetoothKillswitch *kill_switch, KillswitchState state, gpointer user_data)
+killswitch_state_change (BluetoothKillswitch *kill_switch, BluetoothKillswitchState state, gpointer user_data)
 {
   BluetoothApplet *self = BLUETOOTH_APPLET (user_data);
 
@@ -1024,11 +1024,11 @@ bluetooth_applet_class_init (BluetoothAppletClass *klass)
 	gobject_class->get_property = bluetooth_applet_get_property;
 	gobject_class->set_property = bluetooth_applet_set_property;
 
 	/* should be enum, but KillswitchState is not registered */
 	properties[PROP_KILLSWITCH_STATE] = g_param_spec_int ("killswitch-state",
 							      "Killswitch state",
 							      "State of Bluetooth hardware switches",
-							      KILLSWITCH_STATE_NO_ADAPTER, KILLSWITCH_STATE_HARD_BLOCKED, KILLSWITCH_STATE_NO_ADAPTER,
+							      BLUETOOTH_KILLSWITCH_STATE_NO_ADAPTER, BLUETOOTH_KILLSWITCH_STATE_HARD_BLOCKED, BLUETOOTH_KILLSWITCH_STATE_NO_ADAPTER,
 							      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (gobject_class, PROP_KILLSWITCH_STATE, properties[PROP_KILLSWITCH_STATE]);
 
@@ -1024,11 +1024,11 @@ bluetooth_applet_class_init (BluetoothAppletClass *klass)
 	gobject_class->set_property = bluetooth_applet_set_property;
 
-	/* should be enum, but KillswitchState is not registered */
+	/* should be enum, but BluetoothKillswitchState is not registered */
 	properties[PROP_KILLSWITCH_STATE] = g_param_spec_int ("killswitch-state",
 							      "Killswitch state",